=======================================
Welcome to skeleton's documentation!
=======================================

:Author: Damien Lebrun <dinoboff@gmail.com>
:Date: |today|
:Description: Basic Template system for project skeleton.


.. toctree::
   :maxdepth: 2
   
   overview
   api
   history

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`